import React, { PropTypes } from 'react'
import styled, { css, keyframes } from 'styled-components'
import Pane from './Pane'

// TODO: clean up hardcoded values with Color
const fadeInAnimation = keyframes`
  from {
    background-color: rgba(66,94,120,.0);
  }
  to {
    background-color: rgba(66,94,120,.8);
  }
`

const fadeOutAnimation = keyframes`
  from {
    background-color: rgba(66,94,120,.8);
  }
  to {
    background-color: rgba(66,94,120,.0);
  }
`

const styles = ({
  fadeOut,
  theme
}) => css`
  z-index: 10;
  transform: translateZ(0);
  animation: ${fadeOut ? fadeOutAnimation : fadeInAnimation} ${theme.animationDuration.slow} ${theme.animationEasing.standard};
`

const OverlayPane = styled(({ fadeOut, ...props }) =>
  <Pane {...props} />)`${styles}`

OverlayPane.propTypes = {
  ...Pane.propType,
  fadeOut: PropTypes.bool
}

OverlayPane.defaultProps = {
  position: 'fixed',
  top: 0,
  right: 0,
  bottom: 0,
  left: 0,
  backgroundColor: 'rgba(66, 94, 120, .8)'
}

OverlayPane.displayName = 'OverlayPane'

class Overlay extends React.Component {
  componentDidMount() {
    document.body.style.overflow = 'hidden'
  }

  componentWillUnmount() {
    document.body.style.overflow = 'initial'
  }

  render() {
    return <OverlayPane {...this.props} />
  }
}

export default Overlay
