import React, { PropTypes } from 'react'
import styled from 'styled-components'
import Box from './Box'

const getInteractiveStyles = (context) => `
  &:hover,
  &:active {
    border-color: ${context.borderColorInteractive} !important;
  }
`

const getContextStyles = (context, interactive) => `
  background-color: ${context.backgroundColor};
  color: ${context.textColor};
  border-color: ${context.borderColor} !important;

  ${interactive ? getInteractiveStyles(context) : ''}
`

const getValue = (val) => Number.isInteger(val) ? val - 1 : 0

const getStyle = ({ dark, tint, white, interactive }, theme) => {
  let context
  if (white) context = theme.context.white[getValue(white)]
  if (tint) context = theme.context.tint[getValue(tint)]
  if (dark) context = theme.context.dark[getValue(dark)]

  if (context) return getContextStyles(context, interactive)
  return ''
}

const styles = ({
  dark,
  tint,
  white,
  interactive,
  theme
}) => `
  position: relative;
  ${getStyle({ dark, tint, white, interactive }, theme)}
`

const Pane = styled(({ dark, tint, white, interactive, ...props }) =>
  React.createElement(Box, props))`${styles}`

Pane.propTypes = {
  ...Box.propTypes,
  dark: PropTypes.bool,
  tint: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2])
  ]),
  white: PropTypes.bool,
  interactive: PropTypes.bool
}

Pane.displayName = 'Pane'

export default Pane
